summaryrefslogtreecommitdiff
path: root/exercises/060_floats.zig
diff options
context:
space:
mode:
Diffstat (limited to 'exercises/060_floats.zig')
-rw-r--r--exercises/060_floats.zig6
1 files changed, 3 insertions, 3 deletions
diff --git a/exercises/060_floats.zig b/exercises/060_floats.zig
index 217c265..b570518 100644
--- a/exercises/060_floats.zig
+++ b/exercises/060_floats.zig
@@ -41,14 +41,14 @@ pub fn main() void {
// The approximate weight of the Space Shuttle upon liftoff
// (including boosters and fuel tank) was 4,480,000 lb.
//
// We'll convert this weight from pound to kilograms at a
// conversion of 0.453592kg to the pound.
const shuttle_weight: f16 = 0.453592 * 4480e3;
// By default, float values are formatted in scientific
// notation. Try experimenting with '{d}' and '{d:.3}' to see
// how decimal formatting works.
- print("Shuttle liftoff weight: {d:.0}kg\n", .{shuttle_weight});
+ print("Shuttle liftoff weight: {d:.0} metric tons\n", .{shuttle_weight});
}
// Floating further:
@@ -41,14 +41,14 @@ pub fn main() void {
// (including boosters and fuel tank) was 4,480,000 lb.
//
- // We'll convert this weight from pound to kilograms at a
- // conversion of 0.453592kg to the pound.
+ // We'll convert this weight from pounds to metric units at a
+ // conversion of 0.453592 kg to the pound.
const shuttle_weight: f16 = 0.453592 * 4480e3;
// By default, float values are formatted in scientific